import React from 'react';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Rocket, Code, Shield, Globe, Cpu, Database, Lock, CpuIcon, Brain, Server, Smartphone } from 'lucide-react';

interface AboutUsSectionProps {
  id?: string;
  className?: string;
}

const AboutUsSection: React.FC<AboutUsSectionProps> = ({ id, className = '' }) => {
  const features = [
    {
      icon: <Rocket className="h-8 w-8" />,
      title: 'Our Mission',
      description: 'To revolutionize the way people interact with technology by making it accessible, secure, and user-friendly for everyone.'
    },
    {
      icon: <Code className="h-8 w-8" />,
      title: 'Our Vision',
      description: 'Creating a future where technology empowers individuals and communities to achieve their full potential.'
    },
    {
      icon: <Shield className="h-8 w-8" />,
      title: 'Our Values',
      description: 'Transparency, security, and innovation are at the core of everything we do. We believe in building trust through open communication.'
    },
    {
      icon: <Globe className="h-8 w-8" />,
      title: 'Global Impact',
      description: 'We\'re committed to creating solutions that have a positive impact on communities worldwide.'
    }
  ];

  const technologies = [
    {
      icon: <Cpu className="h-6 w-6" />,
      name: 'AI & Machine Learning',
      description: 'Advanced algorithms powering intelligent solutions.'
    },
    {
      icon: <Database className="h-6 w-6" />,
      name: 'Blockchain',
      description: 'Secure and transparent decentralized technology.'
    },
    {
      icon: <Brain className="h-6 w-6" />,
      name: 'Neural Networks',
      description: 'Deep learning models for complex problem-solving.'
    },
    {
      icon: <Server className="h-6 w-6" />,
      name: 'Cloud Computing',
      description: 'Scalable infrastructure for global reach.'
    },
    {
      icon: <Lock className="h-6 w-6" />,
      name: 'Cybersecurity',
      description: 'Enterprise-grade security measures.'
    },
    {
      icon: <Smartphone className="h-6 w-6" />,
      name: 'Cross-Platform',
      description: 'Seamless experience across all devices.'
    }
  ];

  return (
    <div id={id} className={`bg-background ${className}`}>
      {/* Hero Section */}
      <section className="py-20">
        <div className="container mx-auto px-4">
          <div className="max-w-4xl mx-auto text-center">
            <h1 className="text-4xl md:text-5xl mb-6">About Us</h1>
            <p className="text-xl text-muted-foreground mb-8 max-w-3xl mx-auto">
              We are a passionate team of innovators, developers, and visionaries dedicated to building the future of technology.
            </p>
            <div className="flex flex-wrap justify-center gap-4">
              <Button size="lg">Learn More</Button>
              <Button variant="outline" size="lg">Contact Us</Button>
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="py-16 bg-muted/50 dark:bg-muted/20">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl text-center mb-12">Our Core Principles</h2>
          <div className="grid md:grid-cols-2 mx-auto max-w-7xl gap-8 mb-10">
            {features.map((feature, index) => (
              <Card
                key={index}
                className="group relative overflow-hidden rounded-2xl border border-muted bg-background p-6 shadow-sm transition-transform duration-300 hover:scale-[1.02] hover:shadow-lg"
              >
                <CardHeader className="p-0">
                  <div className="flex items-start gap-4">
                    <div className="flex h-12 w-12 items-center justify-center text-primary text-xl">
                      {feature.icon}
                    </div>
                    <div>
                      <CardTitle className="text-lg font-semibold">
                        {feature.title}
                      </CardTitle>
                      <p className="mt-2 text-sm text-muted-foreground">
                        {feature.description}
                      </p>
                    </div>
                  </div>
                </CardHeader>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Technology Stack Section */}
      <section className="py-20">
        <div className="container mx-auto px-4">
          <div className="text-center mb-16">
            <h2 className="text-3xl  mb-4">Our Technology Stack</h2>
            <p className="text-xl text-muted-foreground max-w-3xl mx-auto">
              We leverage cutting-edge technologies to build powerful and scalable solutions
            </p>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 max-w-7xl mx-auto">
            {technologies.map((tech, index) => (
              <Card key={index} className="hover:shadow-md transition-shadow">
                <CardHeader className="flex flex-row items-center space-x-4 pb-2">
                  <div className="p-2 rounded-md bg-primary/10">
                    {tech.icon}
                  </div>
                  <CardTitle className="text-lg">{tech.name}</CardTitle>
                </CardHeader>
                <CardContent>
                  <p className="text-sm text-muted-foreground">{tech.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>
    </div>
  );
};

export default AboutUsSection;