import React from 'react';
import { FiServer, FiZap, FiDollarSign, FiUsers, FiCheck } from 'react-icons/fi';

const mcps = [
  {
    name: "Image Captioning MCP",
    description: "Generate accurate captions for images using state-of-the-art AI models.",
    features: [
      "Accepts image uploads",
      "Returns natural language captions",
      "Supports multiple languages"
    ],
    icon: <FiServer className="w-6 h-6 text-blue-500" />,
    author: "Ben Johnson",
    price: "$0.01 / image",
    data: "Isolated - Verified",
    dataStoring: true,
    credentialsStoring: false,
  },
  {
    name: "Sentiment Analysis MCP",
    description: "Analyze the sentiment of any text and get instant feedback.",
    features: [
      "Real-time analysis",
      "Positive/Negative/Neutral output",
      "API & UI integration"
    ],
    icon: <FiZap className="w-6 h-6 text-yellow-500" />,
    author: "Cayla Hawkins",
    price: "$0.005 / request",
    data: "Shared - Verified",
    dataStoring: true,
    credentialsStoring: true,
  },
  {
    name: "Text-to-Speech MCP",
    description: "Convert written text into realistic speech audio.",
    features: [
      "Multiple voices",
      "Fast response",
      "Downloadable MP3"
    ],
    icon: <FiUsers className="w-6 h-6 text-purple-500" />,
    author: "Toby Shmidt",
    price: "$0.02 / 1000 chars",
    data: "Isolated - Verified",
    dataStoring: false,
    credentialsStoring: false,
  },
  {
    name: "Paywall API MCP",
    description: "Easily monetize your APIs with built-in paywall and analytics.",
    features: [
      "Stripe integration",
      "Usage analytics",
      "Custom pricing"
    ],
    icon: <FiDollarSign className="w-6 h-6 text-green-500" />,
    author: "Sara Lee",
    price: "$0.10 / 100 calls",
    data: "Shared - Verified",
    dataStoring: true,
    credentialsStoring: true,
  }
];

const SampleMCPs = () => {
  return (
    <div className="space-y-8">
      <div className="space-y-4">
        <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
          Sample MCP Servers
        </h3>
        <p className="text-gray-600 dark:text-gray-300 leading-relaxed">
          Explore a few example MCPs you can build, deploy, and monetize on the Fastcode platform.
        </p>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        {mcps.map((mcp) => (
          <div
            key={mcp.name}
            className="flex flex-col gap-3 p-6 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:scale-105 transition-all duration-300"
          >
            <div className="flex items-center gap-3">
              {mcp.icon}
              <h4 className="font-medium text-gray-900 dark:text-white">{mcp.name}</h4>
              <span className="ml-auto text-xs px-2 py-1 rounded truncate text-green-700 dark:text-green-200">{mcp.price}</span>
            </div>
            <div className="text-sm text-gray-600 dark:text-gray-300">{mcp.description}</div>
            <ul className="list-disc list-inside text-xs text-gray-500 dark:text-gray-400 pl-2">
              {mcp.features.map((feature, i) => (
                <li key={i}>{feature}</li>
              ))}
            </ul>
            <div className="flex flex-wrap gap-2 mt-2 text-xs">
              <span className="flex items-center gap-1 px-2 py-1 rounded-full bg-blue-100 dark:bg-blue-900 text-blue-700 dark:text-blue-200">
                {mcp.data} <FiCheck className="inline w-4 h-4 text-green-500" />
              </span>
              <span className="flex items-center gap-1 px-2 py-1 rounded-full bg-gray-100 dark:bg-gray-800 text-gray-700 dark:text-gray-300">
                Data storing {mcp.dataStoring && <FiCheck className="inline w-4 h-4 text-green-500" />}
              </span>
              <span className="flex items-center gap-1 px-2 py-1 rounded-full bg-gray-100 dark:bg-gray-800 text-gray-700 dark:text-gray-300">
                Credentials storing {mcp.credentialsStoring && <FiCheck className="inline w-4 h-4 text-green-500" />}
              </span>
            </div>
            <div className="text-xs text-gray-400 dark:text-gray-500 mt-2">By {mcp.author}</div>
          </div>
        ))}
      </div>
    </div>
  );
};

export default SampleMCPs;